# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import autonml.core_pb2 as core__pb2


class CoreStub(object):
    """See each message's comments for information about each particular call.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SearchSolutions = channel.unary_unary(
                '/Core/SearchSolutions',
                request_serializer=core__pb2.SearchSolutionsRequest.SerializeToString,
                response_deserializer=core__pb2.SearchSolutionsResponse.FromString,
                )
        self.GetSearchSolutionsResults = channel.unary_stream(
                '/Core/GetSearchSolutionsResults',
                request_serializer=core__pb2.GetSearchSolutionsResultsRequest.SerializeToString,
                response_deserializer=core__pb2.GetSearchSolutionsResultsResponse.FromString,
                )
        self.EndSearchSolutions = channel.unary_unary(
                '/Core/EndSearchSolutions',
                request_serializer=core__pb2.EndSearchSolutionsRequest.SerializeToString,
                response_deserializer=core__pb2.EndSearchSolutionsResponse.FromString,
                )
        self.StopSearchSolutions = channel.unary_unary(
                '/Core/StopSearchSolutions',
                request_serializer=core__pb2.StopSearchSolutionsRequest.SerializeToString,
                response_deserializer=core__pb2.StopSearchSolutionsResponse.FromString,
                )
        self.DescribeSolution = channel.unary_unary(
                '/Core/DescribeSolution',
                request_serializer=core__pb2.DescribeSolutionRequest.SerializeToString,
                response_deserializer=core__pb2.DescribeSolutionResponse.FromString,
                )
        self.ScoreSolution = channel.unary_unary(
                '/Core/ScoreSolution',
                request_serializer=core__pb2.ScoreSolutionRequest.SerializeToString,
                response_deserializer=core__pb2.ScoreSolutionResponse.FromString,
                )
        self.GetScoreSolutionResults = channel.unary_stream(
                '/Core/GetScoreSolutionResults',
                request_serializer=core__pb2.GetScoreSolutionResultsRequest.SerializeToString,
                response_deserializer=core__pb2.GetScoreSolutionResultsResponse.FromString,
                )
        self.FitSolution = channel.unary_unary(
                '/Core/FitSolution',
                request_serializer=core__pb2.FitSolutionRequest.SerializeToString,
                response_deserializer=core__pb2.FitSolutionResponse.FromString,
                )
        self.GetFitSolutionResults = channel.unary_stream(
                '/Core/GetFitSolutionResults',
                request_serializer=core__pb2.GetFitSolutionResultsRequest.SerializeToString,
                response_deserializer=core__pb2.GetFitSolutionResultsResponse.FromString,
                )
        self.ProduceSolution = channel.unary_unary(
                '/Core/ProduceSolution',
                request_serializer=core__pb2.ProduceSolutionRequest.SerializeToString,
                response_deserializer=core__pb2.ProduceSolutionResponse.FromString,
                )
        self.GetProduceSolutionResults = channel.unary_stream(
                '/Core/GetProduceSolutionResults',
                request_serializer=core__pb2.GetProduceSolutionResultsRequest.SerializeToString,
                response_deserializer=core__pb2.GetProduceSolutionResultsResponse.FromString,
                )
        self.SolutionExport = channel.unary_unary(
                '/Core/SolutionExport',
                request_serializer=core__pb2.SolutionExportRequest.SerializeToString,
                response_deserializer=core__pb2.SolutionExportResponse.FromString,
                )
        self.DataAvailable = channel.unary_unary(
                '/Core/DataAvailable',
                request_serializer=core__pb2.DataAvailableRequest.SerializeToString,
                response_deserializer=core__pb2.DataAvailableResponse.FromString,
                )
        self.ListPrimitives = channel.unary_unary(
                '/Core/ListPrimitives',
                request_serializer=core__pb2.ListPrimitivesRequest.SerializeToString,
                response_deserializer=core__pb2.ListPrimitivesResponse.FromString,
                )
        self.Hello = channel.unary_unary(
                '/Core/Hello',
                request_serializer=core__pb2.HelloRequest.SerializeToString,
                response_deserializer=core__pb2.HelloResponse.FromString,
                )
        self.SaveSolution = channel.unary_unary(
                '/Core/SaveSolution',
                request_serializer=core__pb2.SaveSolutionRequest.SerializeToString,
                response_deserializer=core__pb2.SaveSolutionResponse.FromString,
                )
        self.LoadSolution = channel.unary_unary(
                '/Core/LoadSolution',
                request_serializer=core__pb2.LoadSolutionRequest.SerializeToString,
                response_deserializer=core__pb2.LoadSolutionResponse.FromString,
                )
        self.SaveFittedSolution = channel.unary_unary(
                '/Core/SaveFittedSolution',
                request_serializer=core__pb2.SaveFittedSolutionRequest.SerializeToString,
                response_deserializer=core__pb2.SaveFittedSolutionResponse.FromString,
                )
        self.LoadFittedSolution = channel.unary_unary(
                '/Core/LoadFittedSolution',
                request_serializer=core__pb2.LoadFittedSolutionRequest.SerializeToString,
                response_deserializer=core__pb2.LoadFittedSolutionResponse.FromString,
                )
        self.SplitData = channel.unary_stream(
                '/Core/SplitData',
                request_serializer=core__pb2.SplitDataRequest.SerializeToString,
                response_deserializer=core__pb2.SplitDataResponse.FromString,
                )
        self.ScorePredictions = channel.unary_unary(
                '/Core/ScorePredictions',
                request_serializer=core__pb2.ScorePredictionsRequest.SerializeToString,
                response_deserializer=core__pb2.ScorePredictionsResponse.FromString,
                )


class CoreServicer(object):
    """See each message's comments for information about each particular call.
    """

    def SearchSolutions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSearchSolutionsResults(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EndSearchSolutions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StopSearchSolutions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DescribeSolution(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ScoreSolution(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetScoreSolutionResults(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FitSolution(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFitSolutionResults(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ProduceSolution(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProduceSolutionResults(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SolutionExport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DataAvailable(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPrimitives(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Hello(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SaveSolution(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LoadSolution(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SaveFittedSolution(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LoadFittedSolution(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SplitData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ScorePredictions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CoreServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SearchSolutions': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchSolutions,
                    request_deserializer=core__pb2.SearchSolutionsRequest.FromString,
                    response_serializer=core__pb2.SearchSolutionsResponse.SerializeToString,
            ),
            'GetSearchSolutionsResults': grpc.unary_stream_rpc_method_handler(
                    servicer.GetSearchSolutionsResults,
                    request_deserializer=core__pb2.GetSearchSolutionsResultsRequest.FromString,
                    response_serializer=core__pb2.GetSearchSolutionsResultsResponse.SerializeToString,
            ),
            'EndSearchSolutions': grpc.unary_unary_rpc_method_handler(
                    servicer.EndSearchSolutions,
                    request_deserializer=core__pb2.EndSearchSolutionsRequest.FromString,
                    response_serializer=core__pb2.EndSearchSolutionsResponse.SerializeToString,
            ),
            'StopSearchSolutions': grpc.unary_unary_rpc_method_handler(
                    servicer.StopSearchSolutions,
                    request_deserializer=core__pb2.StopSearchSolutionsRequest.FromString,
                    response_serializer=core__pb2.StopSearchSolutionsResponse.SerializeToString,
            ),
            'DescribeSolution': grpc.unary_unary_rpc_method_handler(
                    servicer.DescribeSolution,
                    request_deserializer=core__pb2.DescribeSolutionRequest.FromString,
                    response_serializer=core__pb2.DescribeSolutionResponse.SerializeToString,
            ),
            'ScoreSolution': grpc.unary_unary_rpc_method_handler(
                    servicer.ScoreSolution,
                    request_deserializer=core__pb2.ScoreSolutionRequest.FromString,
                    response_serializer=core__pb2.ScoreSolutionResponse.SerializeToString,
            ),
            'GetScoreSolutionResults': grpc.unary_stream_rpc_method_handler(
                    servicer.GetScoreSolutionResults,
                    request_deserializer=core__pb2.GetScoreSolutionResultsRequest.FromString,
                    response_serializer=core__pb2.GetScoreSolutionResultsResponse.SerializeToString,
            ),
            'FitSolution': grpc.unary_unary_rpc_method_handler(
                    servicer.FitSolution,
                    request_deserializer=core__pb2.FitSolutionRequest.FromString,
                    response_serializer=core__pb2.FitSolutionResponse.SerializeToString,
            ),
            'GetFitSolutionResults': grpc.unary_stream_rpc_method_handler(
                    servicer.GetFitSolutionResults,
                    request_deserializer=core__pb2.GetFitSolutionResultsRequest.FromString,
                    response_serializer=core__pb2.GetFitSolutionResultsResponse.SerializeToString,
            ),
            'ProduceSolution': grpc.unary_unary_rpc_method_handler(
                    servicer.ProduceSolution,
                    request_deserializer=core__pb2.ProduceSolutionRequest.FromString,
                    response_serializer=core__pb2.ProduceSolutionResponse.SerializeToString,
            ),
            'GetProduceSolutionResults': grpc.unary_stream_rpc_method_handler(
                    servicer.GetProduceSolutionResults,
                    request_deserializer=core__pb2.GetProduceSolutionResultsRequest.FromString,
                    response_serializer=core__pb2.GetProduceSolutionResultsResponse.SerializeToString,
            ),
            'SolutionExport': grpc.unary_unary_rpc_method_handler(
                    servicer.SolutionExport,
                    request_deserializer=core__pb2.SolutionExportRequest.FromString,
                    response_serializer=core__pb2.SolutionExportResponse.SerializeToString,
            ),
            'DataAvailable': grpc.unary_unary_rpc_method_handler(
                    servicer.DataAvailable,
                    request_deserializer=core__pb2.DataAvailableRequest.FromString,
                    response_serializer=core__pb2.DataAvailableResponse.SerializeToString,
            ),
            'ListPrimitives': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPrimitives,
                    request_deserializer=core__pb2.ListPrimitivesRequest.FromString,
                    response_serializer=core__pb2.ListPrimitivesResponse.SerializeToString,
            ),
            'Hello': grpc.unary_unary_rpc_method_handler(
                    servicer.Hello,
                    request_deserializer=core__pb2.HelloRequest.FromString,
                    response_serializer=core__pb2.HelloResponse.SerializeToString,
            ),
            'SaveSolution': grpc.unary_unary_rpc_method_handler(
                    servicer.SaveSolution,
                    request_deserializer=core__pb2.SaveSolutionRequest.FromString,
                    response_serializer=core__pb2.SaveSolutionResponse.SerializeToString,
            ),
            'LoadSolution': grpc.unary_unary_rpc_method_handler(
                    servicer.LoadSolution,
                    request_deserializer=core__pb2.LoadSolutionRequest.FromString,
                    response_serializer=core__pb2.LoadSolutionResponse.SerializeToString,
            ),
            'SaveFittedSolution': grpc.unary_unary_rpc_method_handler(
                    servicer.SaveFittedSolution,
                    request_deserializer=core__pb2.SaveFittedSolutionRequest.FromString,
                    response_serializer=core__pb2.SaveFittedSolutionResponse.SerializeToString,
            ),
            'LoadFittedSolution': grpc.unary_unary_rpc_method_handler(
                    servicer.LoadFittedSolution,
                    request_deserializer=core__pb2.LoadFittedSolutionRequest.FromString,
                    response_serializer=core__pb2.LoadFittedSolutionResponse.SerializeToString,
            ),
            'SplitData': grpc.unary_stream_rpc_method_handler(
                    servicer.SplitData,
                    request_deserializer=core__pb2.SplitDataRequest.FromString,
                    response_serializer=core__pb2.SplitDataResponse.SerializeToString,
            ),
            'ScorePredictions': grpc.unary_unary_rpc_method_handler(
                    servicer.ScorePredictions,
                    request_deserializer=core__pb2.ScorePredictionsRequest.FromString,
                    response_serializer=core__pb2.ScorePredictionsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'Core', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Core(object):
    """See each message's comments for information about each particular call.
    """

    @staticmethod
    def SearchSolutions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Core/SearchSolutions',
            core__pb2.SearchSolutionsRequest.SerializeToString,
            core__pb2.SearchSolutionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSearchSolutionsResults(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/Core/GetSearchSolutionsResults',
            core__pb2.GetSearchSolutionsResultsRequest.SerializeToString,
            core__pb2.GetSearchSolutionsResultsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EndSearchSolutions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Core/EndSearchSolutions',
            core__pb2.EndSearchSolutionsRequest.SerializeToString,
            core__pb2.EndSearchSolutionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StopSearchSolutions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Core/StopSearchSolutions',
            core__pb2.StopSearchSolutionsRequest.SerializeToString,
            core__pb2.StopSearchSolutionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DescribeSolution(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Core/DescribeSolution',
            core__pb2.DescribeSolutionRequest.SerializeToString,
            core__pb2.DescribeSolutionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ScoreSolution(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Core/ScoreSolution',
            core__pb2.ScoreSolutionRequest.SerializeToString,
            core__pb2.ScoreSolutionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetScoreSolutionResults(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/Core/GetScoreSolutionResults',
            core__pb2.GetScoreSolutionResultsRequest.SerializeToString,
            core__pb2.GetScoreSolutionResultsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FitSolution(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Core/FitSolution',
            core__pb2.FitSolutionRequest.SerializeToString,
            core__pb2.FitSolutionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFitSolutionResults(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/Core/GetFitSolutionResults',
            core__pb2.GetFitSolutionResultsRequest.SerializeToString,
            core__pb2.GetFitSolutionResultsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ProduceSolution(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Core/ProduceSolution',
            core__pb2.ProduceSolutionRequest.SerializeToString,
            core__pb2.ProduceSolutionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetProduceSolutionResults(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/Core/GetProduceSolutionResults',
            core__pb2.GetProduceSolutionResultsRequest.SerializeToString,
            core__pb2.GetProduceSolutionResultsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SolutionExport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Core/SolutionExport',
            core__pb2.SolutionExportRequest.SerializeToString,
            core__pb2.SolutionExportResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DataAvailable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Core/DataAvailable',
            core__pb2.DataAvailableRequest.SerializeToString,
            core__pb2.DataAvailableResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPrimitives(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Core/ListPrimitives',
            core__pb2.ListPrimitivesRequest.SerializeToString,
            core__pb2.ListPrimitivesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Hello(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Core/Hello',
            core__pb2.HelloRequest.SerializeToString,
            core__pb2.HelloResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SaveSolution(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Core/SaveSolution',
            core__pb2.SaveSolutionRequest.SerializeToString,
            core__pb2.SaveSolutionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LoadSolution(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Core/LoadSolution',
            core__pb2.LoadSolutionRequest.SerializeToString,
            core__pb2.LoadSolutionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SaveFittedSolution(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Core/SaveFittedSolution',
            core__pb2.SaveFittedSolutionRequest.SerializeToString,
            core__pb2.SaveFittedSolutionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LoadFittedSolution(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Core/LoadFittedSolution',
            core__pb2.LoadFittedSolutionRequest.SerializeToString,
            core__pb2.LoadFittedSolutionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SplitData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/Core/SplitData',
            core__pb2.SplitDataRequest.SerializeToString,
            core__pb2.SplitDataResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ScorePredictions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Core/ScorePredictions',
            core__pb2.ScorePredictionsRequest.SerializeToString,
            core__pb2.ScorePredictionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)




#!/usr/bin/env python3

# File: create_d3m_dataset.py 
# Author(s): Saswati Ray
# Created: Wed Feb 17 06:44:20 EST 2021 
# Description:
# Acknowledgements:
# Copyright (c) 2021 Carnegie Mellon University
# This code is subject to the license terms contained in the code repo.

import json
import argparse
import shutil
import os
from os.path import exists
from d3m.container import Dataset
from d3m.utils import fix_uri
from d3m.container.utils import save_container

# Get file formats for image/audio/video
def getFormat(t):
    if t == "image":
        return {"image/jpeg": ["jpeg", "jpg"]}
    elif t == "text":
        return {"text/plain": ["txt"]}
    elif t == "audio":
        return {
        "audio/wav": [
          "wav"
        ],
        "audio/aiff": [
          "aif",
          "aiff"
        ],
        "audio/flac": [
          "flac"
        ],
        "audio/ogg": [
          "ogg"
        ],
        "audio/mpeg": [
          "mp3"
        ]
      }
    else:
        return {
        "video/mp4": [
          "mp4"
        ]
      }

# Process task time series forecasting
def process_forecasting_task(TRAIN_DATASET_PATH, TEST_DATASET_PATH):
    time_column = input("Please enter column name for date/time column: ")
    grouping_column = input("Please enter column name for grouping/category column: ")

    for PATH in [TRAIN_DATASET_PATH, TEST_DATASET_PATH]:
        with open(PATH+'datasetDoc.json') as f:
            basic_json_dataset = json.load(f)
            columns = basic_json_dataset["dataResources"][0]["columns"]
            for c in columns:
                if c["colName"] == time_column:
                    c["role"].append("timeIndicator")
                    c["role"].append("attribute")
                    c["colType"] = "dateTime"
                elif c["colName"] == grouping_column:
                    c["role"].append("suggestedGroupingKey")
                    c["role"].append("attribute")
                    c["colType"] = "categorical"
        with open(PATH+'datasetDoc.json', "w") as jsonFile:
            json.dump(basic_json_dataset, jsonFile, indent=4)    

# Process task keywords for image, audio, video, text, timeSeries
def process_tasks(tasks, TRAIN_DATASET_PATH, TEST_DATASET_PATH):
    for t in tasks:
        # Multimedia datasets
        if t == "image" or t == "audio" or t == "video" or t == "text":
            trainMediaDir = input("Please enter directory name for TRAIN media files: ")  
            testMediaDir = input("Please enter directory name for TEST media files: ")
            image_column = input("Please enter column name for media files: ")
            media = {}
            media["resID"] = "0"
            media["resPath"] = "media/"
            media["resType"] = t
            media["resFormat"] = getFormat(t)
            media["isCollection"] = True

            for PATH in [TRAIN_DATASET_PATH, TEST_DATASET_PATH]: 
                with open(PATH+'datasetDoc.json') as f:
                    basic_json_dataset = json.load(f)
                columns = basic_json_dataset["dataResources"][0]["columns"]
                for c in columns:
                    if c["colName"] == image_column:
                        c["role"].append("attribute")
                        c["colType"] = "string"
                        c["refersTo"] = {"resID": "0", "resObject": "item"}
                basic_json_dataset["dataResources"].append(media)
                with open(PATH+'datasetDoc.json', "w") as jsonFile:
                    json.dump(basic_json_dataset, jsonFile, indent=4)
            shutil.copytree(trainMediaDir, TRAIN_DATASET_PATH+'media')
            shutil.copytree(testMediaDir, TEST_DATASET_PATH+'media')
        elif t == "timeSeries":
            trainTSDir = input("Please enter directory name for TRAIN TS files: ")
            testTSDir = input("Please enter directory name for TEST TS files: ")
            timeseries_column = input("Please enter column name for timeseries files: ")
            media = {}
            media["resID"] = "0"
            media["resPath"] = "timeseries/"
            media["resType"] = "timeseries"
            media["resFormat"] = {"text/csv": ["csv"]}
            media["isCollection"] = True
            media["columns"] = []
            media["columns"].append({"colIndex": 0, "colName": "time", "colType": "integer", "role": ["timeIndicator"]})

            for PATH in [TRAIN_DATASET_PATH, TEST_DATASET_PATH]:
                with open(PATH+'datasetDoc.json') as f:
                    basic_json_dataset = json.load(f)
                columns = basic_json_dataset["dataResources"][0]["columns"]
                for c in columns:
                    if c["colName"] == timeseries_column:
                        c["role"].append("attribute")
                        c["colType"] = "string"
                        c["refersTo"] = {"resID": "0", "resObject": "item"}
                basic_json_dataset["dataResources"].insert(0, media)
                with open(PATH+'datasetDoc.json', "w") as jsonFile:
                    json.dump(basic_json_dataset, jsonFile, indent=4)
            shutil.copytree(trainTSDir, TRAIN_DATASET_PATH+'timeseries')
            shutil.copytree(testTSDir, TEST_DATASET_PATH+'timeseries')
        elif t == "forecasting":
            process_forecasting_task(TRAIN_DATASET_PATH, TEST_DATASET_PATH)


# Create TRAIN and TEST directories. Creates d3mIndex column for each data file.
def create_directories(DATASET_PATH, PROBLEM_PATH, dataFileName, target_name, basic_json_problem):
    if exists(DATASET_PATH):
        shutil.rmtree(DATASET_PATH)
    if exists(PROBLEM_PATH):
        shutil.rmtree(PROBLEM_PATH)

    dataset = Dataset.load(fix_uri(dataFileName), dataset_id='raw_dataset')
    save_container(dataset, DATASET_PATH)

    colIndex = dataset['learningData'].columns.get_loc(target_name)
    basic_json_problem["inputs"]["data"][0]['targets'][0]['colIndex'] = colIndex
    
    os.makedirs(PROBLEM_PATH)
    with open(PROBLEM_PATH+"/problemDoc.json", "w") as jsonFile:
        json.dump(basic_json_problem, jsonFile, indent=4)
    with open(DATASET_PATH+'datasetDoc.json') as f:
        basic_json_dataset = json.load(f)
    basic_json_dataset["about"]["datasetSchemaVersion"] = "4.1.0"
    basic_json_dataset["about"]["datasetVersion"] = "1.0" 
    with open(DATASET_PATH+'datasetDoc.json', "w") as jsonFile:
        json.dump(basic_json_dataset, jsonFile, indent=4)

def main():
    # Available are the following parameters-
    # Metrics to use are - accuracy, f1Macro, f1Micro, rocAuc, rocAucMacro, rocAucMicro, 
    #                      rSquared, meanSquaredError, meanSquaredError, meanAbsoluteError, 
    #                      normalizedMutualInformation
    # Tasks to use are : video, linkPrediction, graphMatching, forecasting, classification, graph, semiSupervised, text, timeSeries, 
    #                    clustering, collaborativeFiltering, regression, audio, objectDetection, vertexNomination, communityDetection, image, 
    #                    vertexClassification

    # python create_d3m_dataset.py <dataFileName> <testDataFileName> <target> <metric> -t/--tasks
    # Sample command to use: python create_d3m_dataset.py data.csv data.csv Hall_of_Fame f1Macro -t classification -t tabular

    parser = argparse.ArgumentParser(description="Raw dataset specifications")
    parser.add_argument("dataFileName", type=str, help="dataset TRAIN filename")
    parser.add_argument("testDataFileName", type=str, help="dataset TEST filename")
    parser.add_argument("target", type=str, help="Target")
    parser.add_argument("metric", type=str, help="Metric")
    parser.add_argument('-t','--tasks', action='append', help='Task(s)', required=True)
    args = parser.parse_args()
    print(args)

    TRAIN_DATASET_PATH = './raw/TRAIN/dataset_TRAIN/'
    TRAIN_PROBLEM_PATH = './raw/TRAIN/problem_TRAIN/'
    TEST_DATASET_PATH = './raw/TEST/dataset_TEST/'
    TEST_PROBLEM_PATH = './raw/TEST/problem_TEST/'
    # Load default template
    with open('problemRawDoc.json') as f:
        basic_json_problem = json.load(f)
    basic_json_problem["inputs"]["data"][0]['targets'][0]['colName'] = args.target
    basic_json_problem["inputs"]['performanceMetrics'][0]['metric'] = args.metric
    basic_json_problem["about"]['taskKeywords'] = []
    for t in args.tasks:
        basic_json_problem["about"]['taskKeywords'].append(t)
    
    print("Going to create TRAIN files!")
    create_directories(TRAIN_DATASET_PATH, TRAIN_PROBLEM_PATH, args.dataFileName, args.target, basic_json_problem)
    print("Going to create TEST files!")
    create_directories(TEST_DATASET_PATH, TEST_PROBLEM_PATH, args.testDataFileName, args.target, basic_json_problem)

    process_tasks(args.tasks, TRAIN_DATASET_PATH, TEST_DATASET_PATH)

if __name__=="__main__":
    main()



# File: autonml_api.py 
# Author(s): Vedant Sanil
# Created: Wed Feb 17 11:49:20 EST 2022 
# Description:
# Acknowledgements:
# Copyright (c) 2022 Carnegie Mellon University
# This code is subject to the license terms contained in the code repo.

import os
import shutil
import subprocess

class AutonML(object):
    def __init__(self, input_dir, output_dir, timeout=2, numcpus=8):
        self.input_dir = os.path.abspath(input_dir)
        self.output_dir = os.path.abspath(output_dir)
        self.timeout = str(timeout)
        self.numcpus = str(numcpus)
        self.problemPath = os.path.join(self.input_dir, 'TRAIN', 'problem_TRAIN', 'problemDoc.json')

    def run(self):
        proc = subprocess.Popen(['autonml_main', self.input_dir, 
                                self.output_dir, self.timeout, self.numcpus,
                                self.problemPath], stdout=subprocess.PIPE,
                                stderr=subprocess.PIPE)

        output, error = proc.communicate()
        if proc.returncode != 0:
            print(output)
            raise RuntimeError(error.decode())
